# Those constants are used from the library only
BASE_PAL_URL = "https://pal-{}.adyen.com/pal/servlet"
BASE_TERMINAL_URL = "https://postfmapi-{}.adyen.com/postfmapi"
PAL_LIVE_ENDPOINT_URL_TEMPLATE = "https://{}-pal-live" \
                                 ".adyenpayments.com/pal/servlet"
BASE_HPP_URL = "https://{}.adyen.com/hpp"
ENDPOINT_CHECKOUT_TEST = "https://checkout-test.adyen.com"
ENDPOINT_CHECKOUT_LIVE_SUFFIX = "https://{}-checkout-live" \
                                ".adyenpayments.com/checkout"
API_BIN_LOOKUP_VERSION = "v50"
API_CHECKOUT_VERSION = "v69"
API_CHECKOUT_UTILITY_VERSION = "v1"
API_RECURRING_VERSION = "v49"
API_PAYMENT_VERSION = "v64"
API_PAYOUT_VERSION = "v64"
API_TERMINAL_VERSION = "v1"
LIB_VERSION = "7.1.2"
LIB_NAME = "adyen-python-api-library"
